//
//  LSConsoleLoggerProvider.h
//  Lightstreamer client for iOS UCA
//

#import <Foundation/Foundation.h>

#import "LSLoggerProvider.h"


/**
 Logging level.
 */
typedef NS_ENUM(NSInteger, LSConsoleLogLevel) {
    
    /**
     @brief Debug logging level.
     
     This level enables all logging.
     */
	LSConsoleLogLevelDebug= 0,
    
    /**
     @brief Info logging level.
     
     This level enables logging for information, warnings, errors and fatal errors.
     */
	LSConsoleLogLevelInfo= 10,
    
    /**
     @brief Warn logging level.
     
     This level enables logging for warnings, errors and fatal errors.
     */
	LSConsoleLogLevelWarn= 25,
    
    /**
     @brief Error logging level.
     
     This level enables logging for errors and fatal errors.
     */
	LSConsoleLogLevelError= 50,
    
    /**
     @brief Fatal logging level.
     
     This level enables logging for fatal errors only.
     */
	LSConsoleLogLevelFatal= 100
};


/**
 Simple concrete logging provider that logs on the system console.
 
 To be used, an instance of this class has to be passed to the library through the <[LSLightstreamerClient setLoggerProvider:]>.
 */
@interface LSConsoleLoggerProvider : NSObject <LSLoggerProvider>


/**
 @brief Creates an instace of the concrete system console logger.
 
 @param level The desired logging level for this LSConsoleLoggerProvider instance.
 */
- (nonnull instancetype) initWithLevel:(LSConsoleLogLevel)level;


@end
